Discover Packages
github.com/tomdiekmann/icu
internal
output
package
Version:
v0.2.0
Opens a new window with list of versions in this module.
Published: Mar 16, 2026
License: MIT
Opens a new window with license information.
Imports: 7
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
func PrintCSV(data interface{}) error
PrintCSV prints a slice of structs as CSV by first converting to []map[string]interface{}
via JSON round-trip, then using the first record's keys as headers.
func PrintError(err error , exitCode int )
type Meta struct {
Command string `json:"command"`
AthleteID string `json:"athlete_id"`
Timestamp string `json:"timestamp"`
Count int `json:"count,omitempty"`
Filters map[string ]string `json:"filters,omitempty"`
}
const (
ModeAuto Mode = "auto"
ModeTable Mode = "table"
ModeJSON Mode = "json"
ModeCSV Mode = "csv"
)
type Response struct {
Meta Meta `json:"meta"`
Data interface{} `json:"data"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.